@@ -172,29 +172,24 @@ expr_tree_unref (ExprTree *tree)
 char *
 value_string (Value *value)
 {
-	char buffer [40];
-		
 	switch (value->type){
 	case VALUE_STRING:
 		return g_strdup (value->v.str->str);
 
 	case VALUE_INTEGER:
-		snprintf (buffer, sizeof (buffer)-1, "%d", value->v.v_int);
-		break;
+		return g_strdup_printf ("%d", value->v.v_int) ;
 
 	case VALUE_FLOAT:
-		snprintf (buffer, sizeof (buffer)-1, "%g", value->v.v_float);
-		break;
+		return g_strdup_printf ("%g", value->v.v_float) ;
 
 	case VALUE_ARRAY:
-		snprintf (buffer, sizeof (buffer)-1, "ARRAY");
-		break;
+		return g_strdup ("ARRAY") ;
 		
 	case VALUE_CELLRANGE:
-		return g_strdup ("Internal problem");
-
+		break ;
 	}
-	return g_strdup (buffer);
+
+	return g_strdup ("Internal problem") ;
 }
 
 void
@@ -413,6 +408,20 @@ value_get_as_int (Value *v)
 	return (int) v->v.v_float;
 }
 
+static void
+cell_ref_make_absolute (CellRef *cell_ref, int eval_col, int eval_row)
+{
+	g_return_if_fail (cell_ref != NULL);
+
+	if (cell_ref->col_relative)
+		cell_ref-> col = eval_col + cell_ref->col;
+
+	if (cell_ref->row_relative)
+		cell_ref->row = eval_row + cell_ref->row;
+	cell_ref->row_relative = 0 ;
+	cell_ref->col_relative = 0 ;
+}
+
 static Value *
 eval_cell_value (Sheet *sheet, Value *value)
 {
@@ -480,26 +489,37 @@ eval_funcall (Sheet *sheet, ExprTree *tree, int eval_col, int eval_row, char **e
 	{
 		/* Functions that take pre-computed Values */
 		Value **values;
-		int fn_argc;
-		char *arg_type = fd->args;
+		int fn_argc_min=0, fn_argc_max=0, var_len=0 ;
+		char *arg_type = fd->args, *argptr = fd->args;
+	       
+		/* Get variable limits */
+		while (*argptr) {
+			if (*argptr++=='|') {
+				var_len = 1 ;
+				continue ;
+			}
+			if (!var_len)
+				fn_argc_min++ ;
+			fn_argc_max++ ;
+		}
 
-		fn_argc = strlen (fd->args);
+/*		fn_argc = strlen (fd->args); */
 		
-		if (fn_argc != argc){
+		if (argc > fn_argc_max || argc < fn_argc_min) {
 			*error_string = _("Invalid number of arguments");
 			return NULL;
 		}
 
-		values = g_new (Value *, argc);
+		values = g_new (Value *, fn_argc_max);
 		
-		for (arg = 0; l; l = l->next, arg++, arg_type++){
+		for (arg = 0; l; l = l->next, arg++, arg_type++) {
 			ExprTree *t = (ExprTree *) l->data;
 			
 			v = eval_expr (sheet, t, eval_col, eval_row, error_string);
 			if (v == NULL)
 				goto free_list;
-
-			switch (*arg_type){
+			if (*arg_type=='|') arg_type++ ;
+			switch (*arg_type) {
 			case 'f':
 				if (v->type == VALUE_INTEGER ||
 				    v->type == VALUE_FLOAT)
@@ -514,15 +534,28 @@ eval_funcall (Sheet *sheet, ExprTree *tree, int eval_col, int eval_row, char **e
 					*error_string = _("Type mismatch");
 					return NULL;
 				}
+				break ;
+			case 'r':
+				if (v->type != VALUE_CELLRANGE) {
+					free_values (values, arg);
+					*error_string = _("Type mismatch");
+					return NULL;
+				}
+				cell_ref_make_absolute (&v->v.cell_range.cell_a, eval_col, eval_row) ;
+				cell_ref_make_absolute (&v->v.cell_range.cell_b, eval_col, eval_row) ;
+				break ;
 			}
-			
 			values [arg] = v;
 		}
+		while (arg<fn_argc_max)
+			values[arg++] = NULL ;
 		v = fd->fn (fd, values, error_string);
 
 	free_list:
-		for (i = 0; i < arg; i++)
-			value_release (values [i]);
+		for (i = 0; i < arg; i++) {
+			if (values[i] != NULL)
+				value_release (values [i]) ;
+		}
 		g_free (values);
 		return v;
 	}
