@@ -9,6 +9,7 @@ extern FunctionDefinition string_functions [];
 extern FunctionDefinition stat_functions [];
 extern FunctionDefinition finance_functions [];
 extern FunctionDefinition eng_functions [];
+extern FunctionDefinition lookup_functions [];
 
 typedef int (*FunctionIterateCallback)(Sheet *sheet, Value *value, char **error_string, void *);
 
@@ -60,5 +61,13 @@ Value      *function_def_call_with_values (Sheet              *sheet,
 
 void install_symbols (FunctionDefinition *functions);
 
+float_t combin (int n, int k);
+float_t fact (int n);
+Value *
+gnumeric_average (void *tsheet, GList *expr_node_list, int eval_col, int eval_row, char **error_string);
+Value *gnumeric_count       (void *tsheet, GList *expr_node_list,
+			     int eval_col, int eval_row,
+			     char **error_string);
+
 #endif /* GNUMERIC_FUNC_H */
 
